from setuptools import setup

setup(name='gnb_distributions_analyzer',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gnb_distributions_analyzer'],
      author='Amit Kumar Sharma',
      author_email='ksamit1110@gmail.com',
      zip_safe=False)
